@@ -22,7 +22,13 @@
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-control-frame.h>
 #include <gdk/gdkprivate.h>
+#if defined (GDK_WINDOWING_X11)
 #include <gdk/gdkx.h>
+#elif defined (GDK_WINDOWING_WIN32)
+#include <gdk/gdkwin32.h>
+#else
+#error Port to this GDK backend
+#endif
 #include <gdk/gdktypes.h>
 #include <gtk/gtkhbox.h>
 #include <bonobo/bonobo-socket.h>
@@ -120,8 +126,13 @@ impl_Bonobo_ControlFrame_getToplevelId (PortableServer_Servant  servant,
 
 		id = Bonobo_ControlFrame_getToplevelId (frame, ev);
 	} else
+#if defined (GDK_WINDOWING_X11)
 		id = bonobo_control_window_id_from_x11 (
 			GDK_WINDOW_XWINDOW (toplev->window));
+#elif defined (GDK_WINDOWING_WIN32)
+		id = bonobo_control_window_id_from_x11 (
+			(guint32) GDK_WINDOW_HWND (toplev->window));
+#endif
 
 	return id;
 }
@@ -247,7 +258,6 @@ static CORBA_char *
 bonobo_control_frame_get_remote_window_id (BonoboControlFrame *frame,
 					   CORBA_Environment  *ev)
 {
-#ifdef HAVE_GTK_MULTIHEAD
 	CORBA_char  *retval;
 	char        *cookie;
 	int          screen;
@@ -263,10 +273,6 @@ bonobo_control_frame_get_remote_window_id (BonoboControlFrame *frame,
 	g_free (cookie);
 
 	return retval;
-#else
-	return Bonobo_Control_getWindowId (
-				frame->priv->control, "", ev);
-#endif /* HAVE_GTK_MULTIHEAD */
 }
 
 void
@@ -311,10 +317,12 @@ bonobo_control_frame_get_remote_window (BonoboControlFrame *frame,
 		CORBA_free (id);
 
 		{
+			GdkDisplay *display = gtk_widget_get_display (frame->priv->socket);
 			gpointer user_data = NULL;
-			if (gdk_window_lookup (xid)) {
-				gdk_window_get_user_data (gdk_window_lookup (xid),
-							  &user_data);
+			if (gdk_window_lookup_for_display (display, xid)) {
+				gdk_window_get_user_data
+					(gdk_window_lookup_for_display (display, xid),
+					 &user_data);
 				plug = user_data;
 			}
 		}
@@ -482,7 +490,7 @@ bonobo_control_frame_init (BonoboObject *object)
 BONOBO_TYPE_FUNC_FULL (BonoboControlFrame, 
 		       Bonobo_ControlFrame,
 		       PARENT_TYPE,
-		       bonobo_control_frame);
+		       bonobo_control_frame)
 
 /**
  * bonobo_control_frame_control_activate:
@@ -720,7 +728,6 @@ bonobo_control_frame_set_ui_container (BonoboControlFrame *frame,
 	Bonobo_UIContainer old_ui_container;
 
 	g_return_if_fail (BONOBO_IS_CONTROL_FRAME (frame));
-	g_return_if_fail (frame->priv->activated == FALSE);
 
 	old_ui_container = frame->priv->ui_container;
 
@@ -735,6 +742,9 @@ bonobo_control_frame_set_ui_container (BonoboControlFrame *frame,
 
 	/* See ui-faq.txt if this dies on you. */
 	if (ui_container != CORBA_OBJECT_NIL) {
+		if (frame->priv->activated) 
+			g_warning ("Trying to associate an new UI container with an activated control frame");
+		
 		g_assert (CORBA_Object_is_a (
 			ui_container, "IDL:Bonobo/UIContainer:1.0", ev));
 
@@ -1125,6 +1135,9 @@ bonobo_control_frame_get_popup_component (BonoboControlFrame *control_frame,
 	popup_container = Bonobo_Control_getPopupContainer (
 		control_frame->priv->control, ev);
 
+	if (BONOBO_EX (ev))
+		return NULL;
+
 	bonobo_ui_component_set_container (ui_component, popup_container, ev);
 
 	Bonobo_Unknown_unref (popup_container, ev);
