@@ -15,12 +15,49 @@
 
 #include <bonobo/bonobo-ui-xml.h>
 #include <bonobo/bonobo-ui-util.h>
+#include <bonobo/bonobo-ui-toolbar-button-item.h>
 #include <bonobo/bonobo-window.h>
 
 #include <bonobo/bonobo-i18n.h>
 #include <bonobo/bonobo-ui-main.h>
 #include <bonobo/bonobo-ui-preferences.h>
 
+static const char * tame_xpm[] = {
+"24 24 8 1",
+"       c None",
+".      c #FFFFFF",
+"+      c #9E9E9E",
+"@      c #484848",
+"#      c #131313",
+"$      c #CFCFCF",
+"%      c #363636",
+"&      c #000000",
+"                        ",
+"                        ",
+"                        ",
+"                        ",
+"         .....          ",
+"       .........        ",
+"      ...+@#@+...       ",
+"     ..$%&&&&&%$..      ",
+"     ..%&&&&&&&%..      ",
+"    ..+&&&&&&&&&+..     ",
+"    ..@&&&&&&&&&@..     ",
+"    ..#&&&&&&&&&#..     ",
+"    ..@&&&&&&&&&@..     ",
+"    ..+&&&&&&&&&+..     ",
+"     ..%&&&&&&&%..      ",
+"     ..$%&&&&&%$..      ",
+"      ...+@#@+...       ",
+"       .........        ",
+"         .....          ",
+"                        ",
+"                        ",
+"                        ",
+"                        ",
+"                        "
+};
+
 BonoboUIComponent *global_component;
 
 #define PRINT_PREF(spref, pref) \
@@ -74,7 +111,6 @@ cb_do_popup (GtkWindow *window, BonoboWindow *win)
 
 	gtk_widget_show (menu);
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 0);
-	gtk_widget_destroy (menu);
 }
 
 static void
@@ -210,11 +246,16 @@ main (int argc, char **argv)
 		"	<submenu name=\"File\" _label=\"_Ga'\">\n"
 		"		<menuitem name=\"open\" pos=\"bottom\" _label=\"_Open\" verb=\"FileOpen\" pixtype=\"stock\" pixname=\"Open\" _tip=\"Wibble\"/>\n"
 		"		<control name=\"MyControl\"/>\n"
+		"		<control name=\"MyControl2\"/>\n"
 		"		<control name=\"ThisIsEmpty\"/>\n"
 		"		<menuitem name=\"close\" noplace=\"1\" verb=\"FileExit\" _label=\"_CloseA\" _tip=\"hi\""
 		"		pixtype=\"stock\" pixname=\"Close\" accel=\"*Control*q\"/>\n"
 		"	</submenu>\n"
 		"</menu>";
+	char keysa [] =
+		"<keybindings>\n"
+		"   <accel name=\"*Control*3\" id=\"MyFoo\"/>\n"
+		"</keybindings>\n";
 	char simpleb [] =
 		"<submenu name=\"File\" _label=\"_File\">\n"
 		"	<menuitem name=\"open\" _label=\"_OpenB\" pixtype=\"stock\" pixname=\"Open\" _tip=\"Open you fool\"/>\n"
@@ -245,7 +286,9 @@ main (int argc, char **argv)
 		"	<separator/>\n"
 		"	<toolitem name=\"baa\" pixtype=\"stock\" pixname=\"Open\" _label=\"baa\" _tip=\"My 2nd tooltip\" verb=\"testme\"/>\n"
 		"	<control name=\"AControl\" _tip=\"a tip on a control\" hidden=\"0\" vdisplay=\"button\"\n"
-		"	pixtype=\"stock\" pixname=\"Attach\"/>\n"
+		"	pixtype=\"stock\" pixname=\"gtk-italic\" _label=\"EntryControl\" verb=\"OpenEntry\"/>\n"
+		"	<control name=\"BControl\" _tip=\"another tip on a control\" hidden=\"0\"\n"
+		"	pixtype=\"stock\" pixname=\"gtk-stop\"/>\n"
 		"</dockitem>";
 	char toolb [] =
 		"<dockitem name=\"Toolbar\" look=\"icon\" relief=\"none\">\n"
@@ -314,7 +357,7 @@ main (int argc, char **argv)
 		gtk_box_pack_start_defaults (GTK_BOX (box), button);
 
 		path_entry = gtk_entry_new ();
-		gtk_entry_set_text (GTK_ENTRY (path_entry), "/menu/File/toggle");
+		gtk_entry_set_text (GTK_ENTRY (path_entry), "/commands/MyFoo");
 		gtk_widget_show (GTK_WIDGET (path_entry));
 		gtk_box_pack_start_defaults (GTK_BOX (box), path_entry);
 
@@ -385,6 +428,9 @@ main (int argc, char **argv)
 	bonobo_ui_component_set_translate (componenta, "/popups/MyStuff", simpleb, ev);
 	g_assert (!BONOBO_EX (ev));
 
+	bonobo_ui_component_set_translate (componenta, "/", keysa, ev);
+	g_assert (!BONOBO_EX (ev));
+
 	bonobo_ui_component_set_translate (componentb, "/",   toola, ev);
 	g_assert (!BONOBO_EX (ev));
 
@@ -412,23 +458,14 @@ main (int argc, char **argv)
 						ev);
 		bonobo_object_unref (BONOBO_OBJECT (control));
 		g_assert (!BONOBO_EX (ev));
+
+		widget = gtk_menu_item_new_with_mnemonic ("_Foo item");
+		gtk_widget_show (widget);
+		bonobo_ui_component_widget_set (componenta,
+						"/menu/File/MyControl2",
+						widget, ev);
 	}
 
-#ifdef OLD_STUFF
-	{
-		GtkWidget *widget = gtk_entry_new ();
-		BonoboControl *control = bonobo_control_new (widget);
-		
-		gtk_entry_set_text (GTK_ENTRY (widget), "Example text");
-		gtk_widget_show (widget);
-		bonobo_ui_component_object_set (componenta,
-						"/Toolbar/AControl",
-						BONOBO_OBJREF (control),
-						ev);
-		bonobo_object_unref (BONOBO_OBJECT (control));
-		g_assert (!BONOBO_EX (ev));
-	}
-#else
 	{
 		GtkWidget *widget = gtk_entry_new ();
 		
@@ -439,7 +476,16 @@ main (int argc, char **argv)
 						widget, ev);
 		g_assert (!BONOBO_EX (ev));
 	}
-#endif
+	{
+		GtkWidget *widget;
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data (tame_xpm);
+		widget = bonobo_ui_toolbar_button_item_new (pixbuf, "Test Control");
+		gtk_widget_show (widget);
+		bonobo_ui_component_widget_set (componenta,
+						"/Toolbar/BControl",
+						widget, ev);
+		g_assert (!BONOBO_EX (ev));
+	}
 
 	bonobo_ui_component_add_listener (componentb, "MyFoo", toggled_cb, ev);
 	g_assert (!BONOBO_EX (ev));
